pub struct UninitializedPool {
pub address: Pubkey,
pub whirlpools_config: Pubkey,
pub tick_spacing: u16,
pub fee_rate: u16,
pub protocol_fee_rate: u16,
pub token_mint_a: Pubkey,
pub token_mint_b: Pubkey,
}Expand description
Represents an uninitialized pool.
This struct contains the configuration and token details necessary to initialize a pool.
Fields
address: PubkeyThe address of the pool.
whirlpools_config: PubkeyThe whirlpools_config address for the pool.
tick_spacing: u16The spacing between ticks in the pool.
fee_rate: u16The fee rate applied to swaps in the pool.
protocol_fee_rate: u16The protocol’s share of fees.
token_mint_a: PubkeyThe mint address for token A in the pool.
token_mint_b: PubkeyThe mint address for token B in the pool.